// Copyright 2017 Dmitry Tantsur <divius.inside@gmail.com>
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! Compute API implementation bits.

mod base;
mod flavors;
mod keypairs;
mod protocol;
mod servers;

pub use self::base::V2 as ServiceType;
pub use self::flavors::{DetailedFlavorQuery, Flavor, FlavorSummary, FlavorQuery};
pub use self::keypairs::{KeyPair, KeyPairQuery, NewKeyPair};
pub use self::protocol::{AddressType, KeyPairType, RebootType, ServerAddress,
                         ServerFlavor, ServerSortKey, ServerPowerState,
                         ServerStatus};
pub use self::servers::{DetailedServerQuery, NewServer, Server,
                        ServerCreationWaiter, ServerNIC, ServerQuery,
                        ServerStatusWaiter, ServerSummary};
